[gimp] file-jpeg: Use slightly more accurate float DCT during load (Bug #741776)
- From: Mukund Sivaraman <muks src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gimp] file-jpeg: Use slightly more accurate float DCT during load (Bug #741776)
- Date: Sat, 20 Dec 2014 10:55:38 +0000 (UTC)
commit dbd350747e97f34ab5ddd999b67c874ac87967c8
Author: Mukund Sivaraman <muks banu com>
Date: Sat Dec 20 15:36:18 2014 +0530
file-jpeg: Use slightly more accurate float DCT during load (Bug #741776)
plug-ins/file-jpeg/jpeg-load.c | 5 ++++-
1 files changed, 4 insertions(+), 1 deletions(-)
---
diff --git a/plug-ins/file-jpeg/jpeg-load.c b/plug-ins/file-jpeg/jpeg-load.c
index 576d29a..0425961 100644
--- a/plug-ins/file-jpeg/jpeg-load.c
+++ b/plug-ins/file-jpeg/jpeg-load.c
@@ -155,9 +155,12 @@ load_image (const gchar *filename,
/* Step 4: set parameters for decompression */
/* In this example, we don't need to change any of the defaults set by
* jpeg_read_header(), so we do nothing here.
*/
+ cinfo.dct_method = JDCT_FLOAT;
+
/* Step 5: Start decompressor */
jpeg_start_decompress (&cinfo);
[
@@ -155,9 +155,12 @@ load_image (const gchar *filename,
/* Step 4: set parameters for decompression */
/* In this example, we don't need to change any of the defaults set by
- * jpeg_read_header(), so we do nothing here.
+ * jpeg_read_header(), so we do nothing here, except set the DCT
+ * method.
*/
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]